/***************************************************************************                        
 *   Copyright (C) 20088888888 by Jaroslav Reznik <jreznik@redhat.com>            *                        
 *                                                                         *                        
 *   This program is free software; you can redistribute it and/or modify  *                        
 *   it under the terms of the GNU General Public License as published by  *                        
 *   the Free Software Foundation; either version 2 of the License, or     *                        
 *   (at your option) any later version.                                   *                        
 *                                                                         *                        
 *   This program is distributed in the hope that it will be useful,       *                        
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *                        
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *                        
 *   GNU General Public License for more details.                          *                        
 *                                                                         *                        
 *   You should have received a copy of the GNU General Public License     *                        
 *   along with this program; if not, write to the                         *                        
 *   Free Software Foundation, Inc.,                                       *                        
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *                        
 ***************************************************************************/ 

#include "networkstatusapplet.h"

#include <QApplication>
#include <QPainter>

#include <kdebug.h>

#include <plasma/svg.h>
#include <plasma/theme.h>
#include <plasma/animator.h>

NetworkstatusApplet::NetworkstatusApplet(QObject *parent, const QVariantList &args)
    : Plasma::Applet(parent, args),
      m_theme(0),
      m_status(0)
{
    kDebug() << "Loading applet networkstatusapplet";
    setAcceptsHoverEvents(true);
    setHasConfigurationInterface(false);
    resize(128, 128);
    m_theme = new Plasma::Svg(this);
}

void NetworkstatusApplet::init()
{
    m_theme->setImagePath("widgets/networkstatus");
    m_theme->setContainsMultipleImages(false);
    m_theme->resize(contentsRect().size());

    Plasma::DataEngine* networkstatusEngine = dataEngine("networkstatus");
    networkstatusEngine->connectSource("NetworkStatus", this, 1000);
}

void NetworkstatusApplet::constraintsEvent(Plasma::Constraints constraints)
{
}

void NetworkstatusApplet::dataUpdated(const QString& source, const Plasma::DataEngine::Data &data)
{
    m_status = data["status"].toString();

    update();
}

NetworkstatusApplet::~NetworkstatusApplet()
{
}



void NetworkstatusApplet::paintInterface(QPainter *p, const QStyleOptionGraphicsItem *option, const QRect &contentsRect)
{
    Q_UNUSED( option );

    p->setRenderHint(QPainter::SmoothPixmapTransform);
    p->setRenderHint(QPainter::Antialiasing);

    m_theme->paint(p, contentsRect, "globe");
    
    if (m_status == "connected")
    {
        m_theme->paint(p, contentsRect, "connected");
    }
    else
    {
        m_theme->paint(p, contentsRect, "disconnected");
    }
}

#include "networkstatusapplet.moc"
